@@ -152,7 +152,7 @@ extract_from_prescription <- function(txt) {
 
   unit <- extract_dose_unit(output)
 
-  data.frame(raw = txt, output, freq, itvl, dose, unit, optional,
+  data.frame(raw = txt, freq, itvl, dose, unit, optional,
              stringsAsFactors = FALSE)
 }
 
